@@ -15,6 +15,7 @@ from datatools.aug.imgaugments import data_aug
 def get_args():
     parser = argparse.ArgumentParser(description="tools for voc/coco dataset")
     parser.add_argument("--aug_config", "-f", help="the config file of aug (yml)", type=str, required=True, default=None)
+    parser.add_argument("--data_dir", "-i", help="the folder of data", type=str, required=True, default=None)
     args = parser.parse_args()
     return args
 
@@ -22,7 +23,7 @@ def get_args():
 def main():
     args = get_args()
 
-    data_aug(args.aug_config)
+    data_aug(args.aug_config, args.data_dir)
 
 
 if __name__ == '__main__':
